@@ -30,7 +30,6 @@
 #include <sys/types.h>
 #include <dirent.h>
 #include <string.h>
-#include <libgnomevfs/gnome-vfs.h>
 
 #include <libanjuta/anjuta-plugin-manager.h>
 #include <libanjuta/anjuta-marshal.h>
@@ -152,7 +151,7 @@ collect_cycle (AnjutaPluginManager *plugin_manager,
 			if (dep == base_plugin)
 			{
 				*cycle = g_list_prepend (NULL, dep);
-				/* DEBUG_PRINT ("%s ", anjuta_plugin_handle_get_name (dep)); */
+				/* DEBUG_PRINT ("%s", anjuta_plugin_handle_get_name (dep)); */
 				return TRUE;
 			}
 			else
@@ -160,7 +159,7 @@ collect_cycle (AnjutaPluginManager *plugin_manager,
 				if (collect_cycle (plugin_manager, base_plugin, dep, cycle))
 				{
 					*cycle = g_list_prepend (*cycle, dep);
-					/* DEBUG_PRINT ("%s ", anjuta_plugin_handle_get_name (dep)); */
+					/* DEBUG_PRINT ("%s", anjuta_plugin_handle_get_name (dep)); */
 					return TRUE;
 				}
 			}
@@ -731,7 +730,7 @@ plugin_set_update (AnjutaPluginManager *plugin_manager,
 				if (!anjuta_plugin_deactivate (ANJUTA_PLUGIN (anjuta_plugin)))
 				{
 					anjuta_util_dialog_info (GTK_WINDOW (priv->shell),
-								 _("Plugin '%s' do not want to be deactivated"),
+								 _("Plugin '%s' does not want to be deactivated"),
 								 anjuta_plugin_handle_get_name (plugin));
 				}
 			}
@@ -791,7 +790,8 @@ plugin_toggled (GtkCellRendererToggle *cell, char *path_str, gpointer data)
 	GtkTreePath *path;
 	AnjutaPluginHandle *plugin;
 	gboolean enabled;
-	GHashTable *activated_plugins;
+	GList *activated_plugins;
+	GList *node;
 	AnjutaPlugin* plugin_object;
 	
 	path = gtk_tree_path_new_from_string (path_str);
@@ -805,9 +805,15 @@ plugin_toggled (GtkCellRendererToggle *cell, char *path_str, gpointer data)
 			    COL_PLUGIN, &plugin,
 			    -1);
 	
-	if (enabled)
+	/* Activate one plugin can force the loading of other ones, instead of
+	 * searching which plugins have to be activated, we just unmerge all 
+	 * current plugins and merge all plugins after the modification */
+	
+	/* unmerge all plugins */
+	activated_plugins = g_hash_table_get_values (priv->activated_plugins);
+	for (node = g_list_first (activated_plugins); node != NULL; node = g_list_next (node))
 	{
-		plugin_object = g_hash_table_lookup (priv->activated_plugins, plugin);
+		plugin_object = (AnjutaPlugin *)node->data;
 		if (plugin_object &&
 			IANJUTA_IS_PREFERENCES(plugin_object))
 		{
@@ -816,24 +822,29 @@ plugin_toggled (GtkCellRendererToggle *cell, char *path_str, gpointer data)
 									   NULL);
 		}
 	}
-	enabled = !enabled;
-
-	activated_plugins = plugin_set_update (plugin_manager, plugin, enabled);
-	plugin_object = g_hash_table_lookup (priv->activated_plugins, plugin);
+	g_list_free (activated_plugins);
+	
+	plugin_set_update (plugin_manager, plugin, !enabled);
 	
 	/* Make sure that it appears in the preferences. This method
 		can only be called when the preferences dialog is active so
 		it should be save
 	*/
-	if (plugin_object &&
-		IANJUTA_IS_PREFERENCES(plugin_object))
+	activated_plugins = g_hash_table_get_values (priv->activated_plugins);
+	for (node = g_list_first (activated_plugins); node != NULL; node = g_list_next (node))
 	{
-		ianjuta_preferences_merge (IANJUTA_PREFERENCES (plugin_object),
-								   anjuta_shell_get_preferences (ANJUTA_SHELL (priv->shell), NULL),
-								   NULL);
+		plugin_object = (AnjutaPlugin *)node->data;
+		if (plugin_object &&
+			IANJUTA_IS_PREFERENCES(plugin_object))
+		{
+			ianjuta_preferences_merge (IANJUTA_PREFERENCES (plugin_object),
+									   anjuta_shell_get_preferences (ANJUTA_SHELL (priv->shell), NULL),
+									   NULL);
+		}
 	}
-	
-	update_enabled (GTK_TREE_MODEL (store), activated_plugins);
+	g_list_free (activated_plugins);
+
+	update_enabled (GTK_TREE_MODEL (store), priv->activated_plugins);
 	gtk_tree_path_free (path);
 }
 
@@ -990,7 +1001,7 @@ populate_plugin_model (AnjutaPluginManager *plugin_manager,
 					if (icon) {
 						gtk_list_store_set (store, &iter,
 											COL_ICON, icon, -1);
-						gdk_pixbuf_unref (icon);
+						g_object_unref (icon);
 					}
 				}
 				g_free (text);
@@ -1064,7 +1075,7 @@ foreach_remembered_plugin (gpointer key, gpointer value, gpointer user_data)
 			if (icon) {
 				gtk_list_store_set (store, &iter,
 									COL_REM_ICON, icon, -1);
-				gdk_pixbuf_unref (icon);
+				g_object_unref (icon);
 			}
 		}
 		g_free (text);
@@ -1358,7 +1369,7 @@ get_plugin_factory (AnjutaPluginManager *plugin_manager,
 	/* No plugin implementing this interface found */
 	g_set_error (error, ANJUTA_PLUGIN_MANAGER_ERROR,
 					 ANJUTA_PLUGIN_MANAGER_MISSING_FACTORY,
-					 _("No plugin able to load other plugins in %s"), language);
+					 _("No plugin is able to load other plugins in %s"), language);
 	
 	return NULL;
 }
@@ -1420,8 +1431,7 @@ anjuta_plugin_manager_is_active_plugin (AnjutaPluginManager *plugin_manager,
  * Searches the currently available plugins to find the one which
  * implements the given interface as primary interface and returns it. If
  * the plugin is not yet loaded, it will be loaded and activated.
- * The returned object is garanteed to be an implementor of the
- * interface (as exported by the plugin metafile). It only searches
+ * It only searches
  * from the pool of plugin objects loaded in this shell and can only search
  * by primary interface. If there are more objects implementing this primary
  * interface, user might be prompted to select one from them (and might give
@@ -1433,9 +1443,10 @@ anjuta_plugin_manager_is_active_plugin (AnjutaPluginManager *plugin_manager,
  * </programlisting>
  * Notice that this function takes the interface name string as string, unlike
  * anjuta_plugins_get_interface() which takes the type directly.
+ * If no plugin implementing this interface can be found, returns NULL.
  *
  * Return value: The plugin object (subclass of #AnjutaPlugin) which implements
- * the given interface. See #AnjutaPlugin for more detail on interfaces
+ * the given interface or NULL. See #AnjutaPlugin for more detail on interfaces
  * implemented by plugins.
  */
 GObject *
@@ -1502,7 +1513,6 @@ anjuta_plugin_manager_get_plugin (AnjutaPluginManager *plugin_manager,
 	}
 	
 	/* No plugin implementing this interface found */
-	g_warning ("No plugin found implementing %s Interface.", iface_name);
 	return NULL;
 }
 
@@ -1649,30 +1659,24 @@ anjuta_plugin_manager_unload_plugin (AnjutaPluginManager *plugin_manager,
 }
 
 GList*
-anjuta_plugin_manager_query (AnjutaPluginManager *plugin_manager,
-							 const gchar *section_name,
-							 const gchar *attribute_name,
-							 const gchar *attribute_value,
-							 ...)
+anjuta_plugin_manager_list_query (AnjutaPluginManager *plugin_manager,
+							 GList *secs,
+							 GList *anames,
+							 GList *avalues)
 {
 	AnjutaPluginManagerPriv *priv;
-	va_list var_args;
-	GList *secs = NULL;
-	GList *anames = NULL;
-	GList *avalues = NULL;
-	const gchar *sec = section_name;
-	const gchar *aname = attribute_name;
-	const gchar *avalue = attribute_value;
 	GList *selected_plugins = NULL;
+	const gchar *sec;
+	const gchar *aname;
+	const gchar *avalue;
 	GList *available;
 	
-	
 	g_return_val_if_fail (ANJUTA_IS_PLUGIN_MANAGER (plugin_manager), NULL);
 	
 	priv = plugin_manager->priv;
 	available = priv->available_plugins;
 	
-	if (section_name == NULL)
+	if (secs == NULL)
 	{
 		/* If no query is given, select all plugins */
 		while (available)
@@ -1686,38 +1690,9 @@ anjuta_plugin_manager_query (AnjutaPluginManager *plugin_manager,
 		return g_list_reverse (selected_plugins);
 	}
 	
-	g_return_val_if_fail (section_name != NULL, NULL);
-	g_return_val_if_fail (attribute_name != NULL, NULL);
-	g_return_val_if_fail (attribute_value != NULL, NULL);
-	
-	secs = g_list_prepend (secs, g_strdup (section_name));
-	anames = g_list_prepend (anames, g_strdup (attribute_name));
-	avalues = g_list_prepend (avalues, g_strdup (attribute_value));
-	
-	va_start (var_args, attribute_value);
-	while (sec)
-	{
-		sec = va_arg (var_args, const gchar *);
-		if (sec)
-		{
-			aname = va_arg (var_args, const gchar *);
-			if (aname)
-			{
-				avalue = va_arg (var_args, const gchar *);
-				if (avalue)
-				{
-					secs = g_list_prepend (secs, g_strdup (sec));
-					anames = g_list_prepend (anames, g_strdup (aname));
-					avalues = g_list_prepend (avalues, g_strdup (avalue));
-				}
-			}
-		}
-	}
-	va_end (var_args);
-	
-	secs = g_list_reverse (secs);
-	anames = g_list_reverse (anames);
-	avalues = g_list_reverse (avalues);
+	g_return_val_if_fail (secs != NULL, NULL);
+	g_return_val_if_fail (anames != NULL, NULL);
+	g_return_val_if_fail (avalues != NULL, NULL);
 	
 	while (available)
 	{
@@ -1807,11 +1782,77 @@ anjuta_plugin_manager_query (AnjutaPluginManager *plugin_manager,
 		}
 		available = g_list_next (available);
 	}
+	
+	return g_list_reverse (selected_plugins);
+}
+
+GList*
+anjuta_plugin_manager_query (AnjutaPluginManager *plugin_manager,
+							 const gchar *section_name,
+							 const gchar *attribute_name,
+							 const gchar *attribute_value,
+							 ...)
+{
+	va_list var_args;
+	GList *secs = NULL;
+	GList *anames = NULL;
+	GList *avalues = NULL;
+	const gchar *sec;
+	const gchar *aname;
+	const gchar *avalue;
+	GList *selected_plugins;
+	
+	
+	if (section_name == NULL)
+	{
+		/* If no query is given, select all plugins */
+		return anjuta_plugin_manager_list_query (plugin_manager, NULL, NULL, NULL);
+	}
+	
+	g_return_val_if_fail (section_name != NULL, NULL);
+	g_return_val_if_fail (attribute_name != NULL, NULL);
+	g_return_val_if_fail (attribute_value != NULL, NULL);
+	
+	secs = g_list_prepend (secs, g_strdup (section_name));
+	anames = g_list_prepend (anames, g_strdup (attribute_name));
+	avalues = g_list_prepend (avalues, g_strdup (attribute_value));
+	
+	va_start (var_args, attribute_value);
+	do
+	{
+		sec = va_arg (var_args, const gchar *);
+		if (sec)
+		{
+			aname = va_arg (var_args, const gchar *);
+			if (aname)
+			{
+				avalue = va_arg (var_args, const gchar *);
+				if (avalue)
+				{
+					secs = g_list_prepend (secs, g_strdup (sec));
+					anames = g_list_prepend (anames, g_strdup (aname));
+					avalues = g_list_prepend (avalues, g_strdup (avalue));
+				}
+			}
+		}
+	}
+	while (sec);
+	va_end (var_args);
+	
+	secs = g_list_reverse (secs);
+	anames = g_list_reverse (anames);
+	avalues = g_list_reverse (avalues);
+	
+	selected_plugins = anjuta_plugin_manager_list_query (plugin_manager,
+														 secs,
+														 anames,
+														 avalues);
+	
 	anjuta_util_glist_strings_free (secs);
 	anjuta_util_glist_strings_free (anames);
 	anjuta_util_glist_strings_free (avalues);
 	
-	return g_list_reverse (selected_plugins);
+	return selected_plugins;
 }
 
 enum {
@@ -1844,6 +1885,7 @@ anjuta_plugin_manager_select (AnjutaPluginManager *plugin_manager,
 	GtkCellRenderer *renderer;
 	GList *node;
 	GtkWidget *label;
+	GtkWidget *content_area;
 	GtkWidget *sc;
 	GtkWidget *remember_checkbox;
 	gint response;
@@ -1874,8 +1916,9 @@ anjuta_plugin_manager_select (AnjutaPluginManager *plugin_manager,
 	label = gtk_label_new (description);
 	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 	gtk_widget_show (label);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox), label,
-						FALSE, FALSE, 5);
+	content_area = gtk_dialog_get_content_area (GTK_DIALOG (dlg));
+	gtk_box_pack_start (GTK_BOX (content_area), label,
+			    FALSE, FALSE, 5);
 	
 	sc = gtk_scrolled_window_new (NULL, NULL);
 	gtk_widget_show (sc);
@@ -1885,8 +1928,8 @@ anjuta_plugin_manager_select (AnjutaPluginManager *plugin_manager,
 									GTK_POLICY_AUTOMATIC,
 									GTK_POLICY_AUTOMATIC);
 	
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG(dlg)->vbox), sc,
-						TRUE, TRUE, 5);
+	gtk_box_pack_start (GTK_BOX (content_area), sc,
+			    TRUE, TRUE, 5);
 	
 	model = GTK_TREE_MODEL (gtk_list_store_new (N_COLUMNS, GDK_TYPE_PIXBUF,
 										   G_TYPE_STRING, G_TYPE_POINTER));
@@ -1919,7 +1962,7 @@ anjuta_plugin_manager_select (AnjutaPluginManager *plugin_manager,
 		gtk_check_button_new_with_label (_("Remember this selection"));
 	gtk_container_set_border_width (GTK_CONTAINER (remember_checkbox), 10);
 	gtk_widget_show (remember_checkbox);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG(dlg)->vbox), remember_checkbox,
+	gtk_box_pack_start (GTK_BOX (content_area), remember_checkbox,
 						FALSE, FALSE, 0);
 	
 	node = plugin_descriptions;
@@ -1941,6 +1984,7 @@ anjuta_plugin_manager_select (AnjutaPluginManager *plugin_manager,
 			gchar *icon_path = NULL;
 			icon_path = g_strconcat (PACKAGE_PIXMAPS_DIR"/",
 									 icon_filename, NULL);
+			g_free (icon_filename);
 			/* DEBUG_PRINT ("Icon: %s", icon_path); */
 			icon_pixbuf = 
 				gdk_pixbuf_new_from_file (icon_path, NULL);
@@ -1968,19 +2012,20 @@ anjuta_plugin_manager_select (AnjutaPluginManager *plugin_manager,
 		{
 			g_warning ("Plugin does not define Description attribute");
 		}
-		if (!anjuta_plugin_description_get_string (desc,
-												  "Anjuta Plugin",
-												  "Location",
-												  &location))
-		{
-			g_warning ("Plugin does not define Location attribute");
-		}
-		
 		if (plugin_name && plugin_desc)
 		{
 			GtkTreeIter iter;
 			gchar *text;
-			
+
+			if (!anjuta_plugin_description_get_string (desc,
+													  "Anjuta Plugin",
+													  "Location",
+													  &location))
+			{
+				g_warning ("Plugin does not define Location attribute");
+			}
+		
+		
 			text = g_markup_printf_escaped ("<span size=\"larger\" weight=\"bold\">%s</span>\n%s", plugin_name, plugin_desc);
 
 			gtk_list_store_append (GTK_LIST_STORE (model), &iter);
@@ -1996,6 +2041,8 @@ anjuta_plugin_manager_select (AnjutaPluginManager *plugin_manager,
 			
 			selection_ids = g_list_prepend (selection_ids, location);
 		}
+		g_free (plugin_name);
+		g_free (plugin_desc);
 		node = g_list_next (node);
 	}
 	
@@ -2263,7 +2310,7 @@ anjuta_plugin_manager_class_init (AnjutaPluginManagerClass *klass)
 	                                 PROP_SHELL,
 	                                 g_param_spec_object ("shell",
 														  _("Anjuta Shell"),
-														  _("Anjuta shell for which the plugins are"),
+														  _("Anjuta shell for which the plugins are made"),
 														  G_TYPE_OBJECT,
 														  G_PARAM_READABLE |
 														  G_PARAM_WRITABLE |
@@ -2431,7 +2478,8 @@ anjuta_plugin_manager_activate_plugins (AnjutaPluginManager *plugin_manager,
 			icon_path = g_strconcat (PACKAGE_PIXMAPS_DIR"/",
 									 icon_filename, NULL);
 			/* DEBUG_PRINT ("Icon: %s", icon_path); */
-			label = g_strconcat (_("Loaded: "), title, "...", NULL);
+			/* Avoid space in translated string */
+			label = g_strconcat (_("Loaded:"), " ", title, "...", NULL);
 			icon_pixbuf = gdk_pixbuf_new_from_file (icon_path, NULL);
 			if (!icon_pixbuf)
 				g_warning ("Plugin does not define Icon: No such file %s",
@@ -2478,6 +2526,19 @@ on_collect (gpointer key, gpointer value, gpointer user_data)
 	g_free (id);
 }
 
+/**
+ * anjuta_plugin_manager_get_remembered_plugins:
+ * @plugin_manager: A #AnjutaPluginManager object
+ * 
+ * Get the list of plugins loaded when there is a choice between several
+ * ones without asking the user.
+ *
+ * The list format is returned as a string with the format detailed in 
+ * anjuta_plugin_manager_set_remembered_plugins().
+ *
+ * Return value: a newly-allocated string that must be freed with g_free().
+ */
+
 gchar*
 anjuta_plugin_manager_get_remembered_plugins (AnjutaPluginManager *plugin_manager)
 {
@@ -2498,6 +2559,24 @@ on_foreach_remove_true (gpointer k, gpointer v, gpointer d)
 	return TRUE;
 }
 
+/**
+ * anjuta_plugin_manager_set_remembered_plugins:
+ * @plugin_manager: A #AnjutaPluginManager object
+ * @remembered_plugins: A list of prefered plugins
+ * 
+ * Set the list of plugins loaded when there is a choice between several
+ * ones without asking the user.
+ * The list is a string composed of elements separated by ';'. Each element
+ * is defined with "key=value", where key is the list of possible plugins and
+ * the value is the choosen plugin.
+ *
+ * By the example the following element
+ * <programlisting>
+ *   anjuta-symbol-browser:SymbolBrowserPlugin,anjuta-symbol-db:SymbolDBPlugin,=anjuta-symbol-db:SymbolDBPlugin;
+ * </programlisting>
+ * means if Anjuta has to choose between SymbolBrowserPlugin and
+ * SymbolDBPlugin, it will choose SymbolDBPlugin.
+ */
 void
 anjuta_plugin_manager_set_remembered_plugins (AnjutaPluginManager *plugin_manager,
 											  const gchar *remembered_plugins)
