@@ -48,9 +48,9 @@
 #include <unistd.h>
 #include <string.h>
 #include <ctype.h>
-
-#include <gnome.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
+#include <stdlib.h>
+#include <glib/gi18n.h>
+#include <gio/gio.h>
 
 #include <libanjuta/resources.h>
 #include <libanjuta/anjuta-debug.h>
@@ -96,7 +96,7 @@ struct _BreakpointsDBase
 
 	GtkListStore *model;
 	
-	GladeXML *gxml;
+	GtkBuilder *bxml;
 	gchar *cond_history, *loc_history;
 
 	/* Widgets */	
@@ -155,7 +155,11 @@ breakpoint_item_update_from_debugger (BreakpointItem *bi, const IAnjutaDebuggerB
 		bi->bp.file = g_strdup (bp->file);
 		bi->bp.line = bp->line;
 		if ((bi->uri == NULL) && (g_path_is_absolute (bp->file)))
-			bi->uri = gnome_vfs_get_uri_from_local_path (bp->file);
+		{
+			GFile *file = g_file_new_for_path (bp->file);
+			bi->uri = g_file_get_uri (file);
+			g_object_unref (file);
+		}
 	}
 	if (bp->type & IANJUTA_DEBUGGER_BREAKPOINT_ON_FUNCTION)
 	{
@@ -259,7 +263,7 @@ breakpoint_item_new_from_uri (BreakpointsDBase *bd, const gchar* uri, guint line
 	if (uri != NULL)
 	{
 		bi->uri = g_strdup (uri);
-		bi->bp.file = gnome_vfs_get_local_path_from_uri (uri);
+		bi->bp.file = anjuta_util_get_local_path_from_uri (uri);
 		bi->bp.line = line;
 	}
 	bi->bp.enable = enable;
@@ -290,7 +294,7 @@ breakpoint_item_new_from_string (BreakpointsDBase *bd, const gchar* string, cons
 	else if ((uri != NULL) && isdigit (*string))
 	{
 		bi->uri = g_strdup (uri);
-		bi->bp.file = gnome_vfs_get_local_path_from_uri (uri);
+		bi->bp.file = anjuta_util_get_local_path_from_uri (uri);
 		bi->bp.line = strtoul (string, NULL, 10);
 		bi->bp.type = IANJUTA_DEBUGGER_BREAKPOINT_ON_LINE;
 	}
@@ -321,7 +325,9 @@ breakpoint_item_new_from_string (BreakpointsDBase *bd, const gchar* string, cons
 			bi->bp.file = g_strndup (string, ptr - string);
 			if (g_path_is_absolute (bi->bp.file))
 			{
-				bi->uri = gnome_vfs_get_uri_from_local_path (bi->bp.file);
+				GFile *file = g_file_new_for_path (bi->bp.file);
+				bi->uri = g_file_get_uri (file);
+				g_object_unref (file);
 			}
 		}
 	}
@@ -352,10 +358,17 @@ breakpoints_dbase_set_in_editor (BreakpointsDBase *bd, BreakpointItem *bi)
 	if (bi->handle != -1)
 	{
 		line = ianjuta_markable_location_from_handle (ed, bi->handle, NULL);
-
-		/* Remove old mark */
-		ianjuta_markable_unmark (ed, line, BREAKPOINT_ENABLED, NULL);
-		ianjuta_markable_unmark (ed, line, BREAKPOINT_DISABLED,NULL);
+		if (line != 0)
+		{
+			/* Remove old mark */
+			ianjuta_markable_unmark (ed, line, BREAKPOINT_ENABLED, NULL);
+			ianjuta_markable_unmark (ed, line, BREAKPOINT_DISABLED,NULL);
+		}
+		else
+		{
+			/* Mark is already removed, perhaps the file has been reloaded */
+			line = bi->bp.line;
+		}
 	}
 	else
 	{
@@ -1418,7 +1431,7 @@ on_session_load (AnjutaShell *shell, AnjutaSessionPhase phase, AnjutaSession *se
 static void
 breakpoints_dbase_edit_breakpoint (BreakpointsDBase *bd, BreakpointItem *bi)
 {
-	GladeXML *gxml;
+	GtkBuilder *bxml;
 	GtkWidget *dialog;
 	GtkWidget *location_label, *location_entry;
 	GtkWidget *condition_entry, *condition_label;
@@ -1428,17 +1441,21 @@ breakpoints_dbase_edit_breakpoint (BreakpointsDBase *bd, BreakpointItem *bi)
 	gchar *uri = NULL;
 	gboolean new_break = FALSE;
 
-	gxml = glade_xml_new (GLADE_FILE,
-						  "breakpoint_properties_dialog", NULL);
-	dialog = glade_xml_get_widget (gxml, "breakpoint_properties_dialog");
+	bxml = anjuta_util_builder_new (GLADE_FILE, NULL);
+	if (!bxml) return;
+	anjuta_util_builder_get_objects (bxml,
+	    "breakpoint_properties_dialog", &dialog,
+	    "breakpoint_location_label", &location_label,
+	    "breakpoint_location_entry", &location_entry,
+	    "breakpoint_condition_entry", &condition_entry,
+		"breakpoint_condition_label", &condition_label,
+		"breakpoint_pass_entry", &pass_entry,
+		"breakpoint_pass_label", &pass_label,
+	    NULL);
+	g_object_unref (bxml);
+
 	gtk_window_set_transient_for (GTK_WINDOW (dialog),
 								  GTK_WINDOW (ANJUTA_PLUGIN (bd->plugin)->shell));
-	location_label = glade_xml_get_widget (gxml, "breakpoint_location_label");
-	location_entry = glade_xml_get_widget (gxml, "breakpoint_location_entry");
-	condition_entry = glade_xml_get_widget (gxml, "breakpoint_condition_entry");
-	condition_label = glade_xml_get_widget (gxml, "breakpoint_condition_label");
-	pass_entry = glade_xml_get_widget (gxml, "breakpoint_pass_entry");
-	pass_label = glade_xml_get_widget (gxml, "breakpoint_pass_label");
 
 	if (bd->debugger != NULL)
 	{
@@ -1502,7 +1519,7 @@ breakpoints_dbase_edit_breakpoint (BreakpointsDBase *bd, BreakpointItem *bi)
 		location = g_strdup_printf ("*%lx", bi->bp.address);
 	}
 
-	if (GTK_WIDGET_VISIBLE(location_entry))
+	if (gtk_widget_get_visible (location_entry))
 	{
 		gtk_entry_set_text (GTK_ENTRY (location_entry), location == NULL ? "" : location);
 	}
@@ -1529,7 +1546,7 @@ breakpoints_dbase_edit_breakpoint (BreakpointsDBase *bd, BreakpointItem *bi)
 		while (isspace(*condition)) condition++;
 		if (*condition == '\0') condition = NULL;
 
-		if (GTK_WIDGET_VISIBLE(location_entry))
+		if (gtk_widget_get_visible (location_entry))
 		{
 			new_location = gtk_entry_get_text (GTK_ENTRY (location_entry));
 			while (isspace(*new_location)) new_location++;
@@ -1582,7 +1599,6 @@ breakpoints_dbase_edit_breakpoint (BreakpointsDBase *bd, BreakpointItem *bi)
 	g_free (uri);
 	g_free (location);
 	gtk_widget_destroy (dialog);
-	g_object_unref (gxml);
 }
 
 /* Breakpoint actions list
@@ -1774,7 +1790,7 @@ static GtkActionEntry actions_debugger_breakpoints[] = {
 	{
 		"ActionDmaSetBreakpoint",                 /* Action name */
 		ANJUTA_STOCK_BREAKPOINT_ENABLED,          /* Stock icon, if any */
-		N_("Add Breakpoint..."),                  /* Display label */
+		N_("Add Breakpoint…"),                  /* Display label */
 		NULL,                                     /* short-cut */
 		N_("Add a breakpoint"),                   /* Tooltip */
 		G_CALLBACK (on_add_breakpoint_activate)   /* action callback */
@@ -1969,7 +1985,7 @@ create_breakpoint_gui(BreakpointsDBase *bd)
 	anjuta_shell_add_widget (ANJUTA_PLUGIN(bd->plugin)->shell,
 							 bd->window,
 							 "AnjutaDebuggerBreakpoints", _("Breakpoints"),
-							 ANJUTA_STOCK_BREAKPOINT_ENABLED, ANJUTA_SHELL_PLACEMENT_BOTTOM,
+							 ANJUTA_STOCK_BREAKPOINT_ENABLED, ANJUTA_SHELL_PLACEMENT_NONE,
 							 NULL);
 
 	/* Add popup menu */
