@@ -23,8 +23,9 @@
 #include "watch.h"
 
 #include "debug_tree.h"
+#include "utilities.h"
 
-/*#define DEBUG*/
+#include <glib/gi18n.h>
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/interfaces/ianjuta-editor-selection.h>
 #include <libanjuta/interfaces/ianjuta-editor.h>
@@ -61,41 +62,31 @@ typedef struct _InspectDialog InspectDialog;
 #define ADD_WATCH_DIALOG "add_watch_dialog"
 #define CHANGE_WATCH_DIALOG "change_watch_dialog"
 #define INSPECT_EVALUATE_DIALOG "watch_dialog"
-#define NAME_ENTRY "name_entry"
+#define VALUE_TREE "watch_value_treeview"
+#define NAME_ENTRY "add_watch_name_entry"
 #define VALUE_ENTRY "value_entry"
-#define VALUE_TREE "value_treeview"
 #define AUTO_UPDATE_CHECK "auto_update_check"
 
 /* Private functions
  *---------------------------------------------------------------------------*/
 
-#if 0
-static void
-on_entry_updated (const gchar *value, gpointer user_data, GError *err)
-{
-	GtkWidget *entry = GTK_WIDGET (user_data);
-	
-	gtk_entry_set_text (GTK_ENTRY (entry), value);
-	gtk_widget_unref (entry);
-}
-#endif
-
 static void
 debug_tree_inspect_evaluate_dialog (ExprWatch * ew, const gchar* expression)
 {
-	GladeXML *gxml;
+	GtkBuilder *bxml;
 	gint reply;
 	gchar *new_expr;
-	// const gchar *value;
 	InspectDialog dlg;
-	IAnjutaDebuggerVariable var = {NULL, NULL, NULL, NULL, FALSE, -1};
+	IAnjutaDebuggerVariableObject var = {NULL, NULL, NULL, NULL, FALSE, FALSE, FALSE, -1};
 
-	gxml = glade_xml_new (GLADE_FILE, INSPECT_EVALUATE_DIALOG, NULL);
-	dlg.dialog = glade_xml_get_widget (gxml, INSPECT_EVALUATE_DIALOG);
-	gtk_window_set_transient_for (GTK_WINDOW (dlg.dialog),
-								  NULL);
-	dlg.treeview = glade_xml_get_widget (gxml, VALUE_TREE);
-	g_object_unref (gxml);
+	bxml = anjuta_util_builder_new (GLADE_FILE, NULL);
+	if (!bxml) return;
+	anjuta_util_builder_get_objects (bxml,
+	    INSPECT_EVALUATE_DIALOG, &dlg.dialog,
+	    VALUE_TREE, &dlg.treeview,
+	    NULL);
+	g_object_unref (bxml);
+	gtk_window_set_transient_for (GTK_WINDOW (dlg.dialog), NULL);
 
 	/* Create debug tree */
 	dlg.tree = debug_tree_new_with_view (ANJUTA_PLUGIN (ew->plugin), GTK_TREE_VIEW (dlg.treeview));
@@ -110,7 +101,7 @@ debug_tree_inspect_evaluate_dialog (ExprWatch * ew, const gchar* expression)
 	{
 		debug_tree_add_dummy (dlg.tree, NULL);
 	}
-
+	
 	for(;;)
 	{
 		reply = gtk_dialog_run (GTK_DIALOG (dlg.dialog));
@@ -139,20 +130,25 @@ debug_tree_inspect_evaluate_dialog (ExprWatch * ew, const gchar* expression)
 static void
 debug_tree_add_watch_dialog (ExprWatch *ew, const gchar* expression)
 {
-	GladeXML *gxml;
+	GtkBuilder *bxml;
 	GtkWidget *dialog;
 	GtkWidget *name_entry;
 	GtkWidget *auto_update_check;
 	gint reply;
-	IAnjutaDebuggerVariable var = {NULL, NULL, NULL, NULL, FALSE, -1};
+	IAnjutaDebuggerVariableObject var = {NULL, NULL, NULL, NULL, FALSE, FALSE, FALSE, -1};
 
-	gxml = glade_xml_new (GLADE_FILE, ADD_WATCH_DIALOG, NULL);
-	dialog = glade_xml_get_widget (gxml, ADD_WATCH_DIALOG);
+
+	bxml = anjuta_util_builder_new (GLADE_FILE, NULL);
+	if (!bxml) return;
+	anjuta_util_builder_get_objects (bxml,
+	    ADD_WATCH_DIALOG, &dialog,
+	    AUTO_UPDATE_CHECK, &auto_update_check,
+	    NAME_ENTRY, &name_entry,
+	    NULL);
+	g_object_unref (bxml);
+	
 	gtk_window_set_transient_for (GTK_WINDOW (dialog),
 								  NULL);
-	auto_update_check = glade_xml_get_widget (gxml, AUTO_UPDATE_CHECK);
-	name_entry = glade_xml_get_widget (gxml, NAME_ENTRY);
-	g_object_unref (gxml);
 
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (auto_update_check), TRUE);
 	gtk_entry_set_text (GTK_ENTRY (name_entry), expression == NULL ? "" : expression);
@@ -210,24 +206,24 @@ on_program_stopped (ExprWatch *ew)
 }
 
 static void
-on_program_unloaded (ExprWatch *ew)
+on_program_exited (ExprWatch *ew)
 {
 	debug_tree_disconnect (ew->debug_tree);
 
 	/* Disconnect to other debugger signal */
-	g_signal_handlers_disconnect_by_func (ew->plugin, G_CALLBACK (on_program_unloaded), ew);
+	g_signal_handlers_disconnect_by_func (ew->plugin, G_CALLBACK (on_program_exited), ew);
 	g_signal_handlers_disconnect_by_func (ew->plugin, G_CALLBACK (on_program_stopped), ew);
 }
 
 static void
-on_program_loaded (ExprWatch *ew)
+on_program_started (ExprWatch *ew)
 {
-	if (!(dma_debugger_queue_get_feature (ew->debugger) & HAS_VARIABLE)) return;
+	if (!dma_debugger_queue_is_supported (ew->debugger, HAS_VARIABLE)) return;
 
 	debug_tree_connect (ew->debug_tree, ew->debugger);
 	
 	/* Connect to other debugger signal */
-	g_signal_connect_swapped (ew->plugin, "program-unloaded", G_CALLBACK (on_program_unloaded), ew);
+	g_signal_connect_swapped (ew->plugin, "program-exited", G_CALLBACK (on_program_exited), ew);
 	g_signal_connect_swapped (ew->plugin, "program-stopped", G_CALLBACK (on_program_stopped), ew);
 }
 
@@ -238,25 +234,17 @@ static void
 on_debug_tree_inspect (GtkAction *action, gpointer user_data)
 {
 	ExprWatch * ew = (ExprWatch *)user_data;
-	GObject *obj;
-	IAnjutaDocumentManager *docman = NULL;
 	IAnjutaEditor *te = NULL;
 	gchar *expression = NULL;
 	
 	/* Get current editor and line */
-	obj = anjuta_shell_get_object (ANJUTA_PLUGIN (ew->plugin)->shell,
-			"IAnjutaDocumentManager", NULL /* TODO */);
-	docman = IANJUTA_DOCUMENT_MANAGER (obj);
-	if (docman != NULL)
+	te = dma_get_current_editor (ANJUTA_PLUGIN (ew->plugin));
+	if (te == NULL)	return;
+	
+	expression = ianjuta_editor_selection_get (IANJUTA_EDITOR_SELECTION (te), NULL);
+	if (expression == NULL)
 	{
-		te = IANJUTA_EDITOR(ianjuta_document_manager_get_current_document (docman, NULL));
-		if (!te)
-			return;
-		expression = ianjuta_editor_selection_get (IANJUTA_EDITOR_SELECTION (te), NULL);
-		if (expression == NULL)
-		{
-			expression = ianjuta_editor_get_current_word (IANJUTA_EDITOR (te), NULL);
-		}
+		expression = ianjuta_editor_get_current_word (IANJUTA_EDITOR (te), NULL);
 	}
 	
 	debug_tree_inspect_evaluate_dialog (ew, expression);
@@ -381,7 +369,7 @@ static GtkActionEntry actions_watch[] = {
     {
 		"ActionDmaInspect",                      /* Action name */
 		GTK_STOCK_DIALOG_INFO,                   /* Stock icon, if any */
-		N_("Ins_pect/Evaluate..."),              /* Display label */
+		N_("Ins_pect/Evaluate…"),              /* Display label */
 		NULL,                                    /* short-cut */
 		N_("Inspect or evaluate an expression or variable"), /* Tooltip */
 		G_CALLBACK (on_debug_tree_inspect) /* action callback */
@@ -389,7 +377,7 @@ static GtkActionEntry actions_watch[] = {
 	{
 		"ActionDmaAddWatch",                      
 		NULL,                                     
-		N_("Add Watch..."),                      
+		N_("Add Watch…"),                      
 		NULL,                                    
 		NULL,                                     
 		G_CALLBACK (on_debug_tree_add_watch)     
@@ -484,6 +472,12 @@ create_expr_watch_gui (ExprWatch * ew)
 /* Public function
  *---------------------------------------------------------------------------*/
 
+gchar*
+expr_watch_find_variable_value (ExprWatch *ew, const gchar *name)
+{
+	return debug_tree_find_variable_value (ew->debug_tree, name);
+}
+
 /* Callback for saving session
  *---------------------------------------------------------------------------*/
 
@@ -543,7 +537,7 @@ expr_watch_new (AnjutaPlugin *plugin)
                               NULL);
 	
 	/* Connect to debugger */
-	g_signal_connect_swapped (ew->plugin, "program-loaded", G_CALLBACK (on_program_loaded), ew);
+	g_signal_connect_swapped (ew->plugin, "program-started", G_CALLBACK (on_program_started), ew);
 	
 	return ew;
 }
