@@ -85,9 +85,7 @@ on_add_ok_clicked (MacroEdit * edit)
 
 	macro_db_add (edit->macro_db,
 		      gtk_entry_get_text (GTK_ENTRY (edit->name_entry)),
-		      gtk_entry_get_text (GTK_ENTRY
-					  (GTK_BIN (edit->category_entry)->
-					   child)),
+		      gtk_entry_get_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (edit->category_entry)))),
 		      gtk_entry_get_text (GTK_ENTRY (edit->shortcut_entry)),
 		      text);
 	gtk_widget_destroy (GTK_WIDGET (edit));
@@ -118,11 +116,8 @@ on_edit_ok_clicked (MacroEdit * edit)
 
 	macro_db_change (edit->macro_db, &iter,
 			 gtk_entry_get_text (GTK_ENTRY (edit->name_entry)),
-			 gtk_entry_get_text (GTK_ENTRY
-					     (GTK_BIN (edit->category_entry)->
-					      child)),
-			 gtk_entry_get_text (GTK_ENTRY
-					     (edit->shortcut_entry)), text);
+			 gtk_entry_get_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (edit->category_entry)))),
+			 gtk_entry_get_text (GTK_ENTRY (edit->shortcut_entry)), text);
 	gtk_widget_destroy (GTK_WIDGET (edit));
 }
 
@@ -168,7 +163,15 @@ macro_edit_dispose (GObject * edit)
 {
 	//MacroEdit *medit = MACRO_EDIT (edit);
 	//g_object_unref(medit->gxml);
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, dispose, (G_OBJECT (edit)));
+	G_OBJECT_CLASS (parent_class)->dispose (edit);
+}
+
+static void
+macro_edit_finalize (GObject * edit)
+{
+	//MacroEdit *medit = MACRO_EDIT (edit);
+	//g_object_unref(medit->gxml);
+	G_OBJECT_CLASS (parent_class)->finalize (edit);
 }
 
 static void
@@ -177,31 +180,40 @@ macro_edit_class_init (MacroEditClass * klass)
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	parent_class = g_type_class_peek_parent (klass);
 	object_class->dispose = macro_edit_dispose;
+	object_class->finalize = macro_edit_finalize;
 }
 
 static void
 macro_edit_init (MacroEdit * edit)
 {
 	GtkWidget *table;
+	GError* error = NULL;
 
-	edit->gxml = glade_xml_new (GLADE_FILE, "macro_edit_table", NULL);
+	edit->bxml = gtk_builder_new ();
 
-	table = glade_xml_get_widget (edit->gxml, "macro_edit_table");
-	gtk_container_add (GTK_CONTAINER (GTK_DIALOG (edit)->vbox), table);
+	if (!gtk_builder_add_from_file (edit->bxml, GLADE_FILE, &error))
+	{
+		g_warning ("Couldn't load builder file: %s", error->message);
+		g_error_free (error);
+	}
+
+	table = GTK_WIDGET (gtk_builder_get_object (edit->bxml, "macro_edit_table"));
+	gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (edit))),
+			   table);
 	gtk_dialog_add_buttons (GTK_DIALOG (edit), GTK_STOCK_OK, OK,
 				GTK_STOCK_CANCEL, CANCEL, NULL);
 	g_signal_connect (G_OBJECT (edit), "response",
 			  G_CALLBACK (on_dialog_response), edit);
 	gtk_window_set_title (GTK_WINDOW (edit), _("Add/Edit macro"));
 
-	edit->name_entry = glade_xml_get_widget (edit->gxml, "macro_name");
+	edit->name_entry = GTK_WIDGET (gtk_builder_get_object (edit->bxml, "macro_name"));
 	edit->category_entry = gtk_combo_box_entry_new_text ();
 	gtk_widget_show (edit->category_entry);
 	gtk_table_attach_defaults (GTK_TABLE (table),
 				   edit->category_entry, 1, 2, 2, 3);
 	edit->shortcut_entry =
-		glade_xml_get_widget (edit->gxml, "macro_shortcut");
-	edit->text = glade_xml_get_widget (edit->gxml, "macro_text");
+		GTK_WIDGET (gtk_builder_get_object (edit->bxml, "macro_shortcut"));
+	edit->text = GTK_WIDGET (gtk_builder_get_object (edit->bxml, "macro_text"));
 
 }
 
@@ -275,9 +287,8 @@ macro_edit_fill (MacroEdit * edit, GtkTreeSelection * select)
 				g_strdup_printf ("%c", shortcut);
 			gtk_entry_set_text (GTK_ENTRY (edit->name_entry),
 					    name);
-			gtk_entry_set_text (GTK_ENTRY
-					    (GTK_BIN (edit->category_entry)->
-					     child), category);
+			gtk_entry_set_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (edit->category_entry))),
+					    category);
 			gtk_entry_set_text (GTK_ENTRY (edit->shortcut_entry),
 					    shortcut_string);
 			g_free (shortcut_string);
