@@ -70,7 +70,7 @@ symbol_db_engine_find_symbol_by_name_pattern (SymbolDBEngine *dbe,
  *        SYMSEARCH_FILESCOPE_IGNORE to be ignored (e.g. Will search both private and public scopes). 
  *        You cannot use bitwise OR in this parameter.
  * @param session_projects Should the search, a global search, be filtered by some packages (projects)?
- *        If yes then provide a GList, if no then pass NULL.	 
+ *        If yes then provide a GList, if no then pass NULL.
  * @param results_limit Limit results to an upper bound. -1 If you don't want to use this par.
  * @param results_offset Skip results_offset results. -1 If you don't want to use this par.
  * @param sym_info Infos about symbols you want to know.
@@ -81,7 +81,7 @@ symbol_db_engine_find_symbol_by_name_pattern_filtered (SymbolDBEngine *dbe,
 									SymType filter_kinds,
 									gboolean include_kinds,
 									SymSearchFileScope filescope_search,
-									GList *session_projects,													   
+									const GList *session_projects,													   
 									gint results_limit, 
 									gint results_offset,
 									SymExtraInfo sym_info);
@@ -128,6 +128,13 @@ symbol_db_engine_find_symbol_in_scope (SymbolDBEngine *dbe,
 									gint results_offset,    
     								SymExtraInfo sym_info);
 
+/**
+ * TODO: Implement a function that, given a container_symbol_id, is able to determine
+ * if a query_symbol_id is under the scope of container_symbol_id, in a multi level fashion.
+ * Infact it wouldn't be performant to use symbol_db_engine_find_symbol_in_scope ()
+ * and recursively search for every sub-scope looking for the query_symbol_id.
+ */
+
 /**
  * Return an iterator to the data retrieved from database. 
  * The iterator, if not null, will contain a list of parent classes for the 
@@ -204,7 +211,8 @@ symbol_db_engine_get_parent_scope_id_by_symbol_id (SymbolDBEngine *dbe,
  * It includes the calls to symbol_db_engine_get_parent_scope_id_by_symbol_id () and
  * symbol_db_engine_get_symbol_info_by_id (). It's a sort of facade.
  * @param scoped_symbol_id Symbol you want to know the parent of.
- * @param db_file db-relative filename path. eg. /src/foo.c Can be NULL.
+ * @param db_file db-relative filename path. eg. /src/foo.c. Can be NULL for a
+ * wider search (i.e. not just limited to that file).
  * @return NULL on error or if nothing is found as parent.
  */
 SymbolDBEngineIterator *
@@ -230,6 +238,8 @@ symbol_db_engine_get_parent_scope_by_symbol_id (SymbolDBEngine *dbe,
  * 
  * the returned iterator'll contain symbols in this order: foo_func, FooKlass, FooBase.
  *
+ * @param db_file db-relative filename path. eg. /src/foo.c. Can be NULL for a
+ * wider search (i.e. not just limited to that file).
  * @return NULL on error or if scope isn't found.
  */
 SymbolDBEngineIterator *
